Query verbs (select/insert/upsert/update/delete) + rpc + aggregations.
Query verbs (select/insert/upsert/update/delete) + rpc + aggregations.
(delete req)(delete req opts)Deletes rows. Filter first or every row in the relation is deleted.
Deletes rows. Filter first or every row in the relation is deleted.
(insert req data)(insert req data opts)Inserts data (map or vector of maps).
Inserts `data` (map or vector of maps).
(rpc client fn-name)(rpc client fn-name args)(rpc client fn-name args opts)Calls a database function.
Opts: :head — boolean; when true, send HEAD (no body returned) :get — boolean; when true, send GET (args become query params) :count — :exact | :planned | :estimated
Returns a request builder. Pipe through filters or execute to run.
Calls a database function. Opts: :head — boolean; when true, send HEAD (no body returned) :get — boolean; when true, send GET (args become query params) :count — :exact | :planned | :estimated Returns a request builder. Pipe through filters or `execute` to run.
(select req columns)(select req columns opts)Builds a SELECT.
columns is "*", a string, or a vector of strings/keywords.
Opts:
:count — :exact | :planned | :estimated (default :exact)
:returning — boolean; when true, performs GET; when false, HEAD
(default false — only headers + count are returned)
Builds a SELECT.
`columns` is `"*"`, a string, or a vector of strings/keywords.
Opts:
:count — :exact | :planned | :estimated (default :exact)
:returning — boolean; when true, performs GET; when false, HEAD
(default false — only headers + count are returned)(update req data)(update req data opts)Updates rows with data. Filter the rows with eq/gt/... before
calling, or every row matching the relation will be updated.
Updates rows with `data`. Filter the rows with `eq`/`gt`/... before calling, or every row matching the relation will be updated.
(upsert req data)(upsert req data opts)Upserts data. Defaults to resolution=merge-duplicates.
Upserts `data`. Defaults to `resolution=merge-duplicates`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |